==> tdm_2.0.0.tar.gz: tdm/R/all.Amidihirms.R <==
all.Amidihirms<-function(){
     cat("\n")                                                                       
     cat("--------------------------------------------------------------\n")
     cat("    --Aminophylline dihydrous IR input data information--     \n")
     note_for_Theirss_input()
     cat("--------------------------------------------------------------\n")
     cat("\n")
     note_for_close_window()
     AmidihirMSpar<-data.frame(subject=c(1,2),Gender=c(0),age=c(0),ht=c(0),CHF=c(0),smoke=c(0),D=c(0),tau=c(0),ts=c(0),c=c(0))
     AmidihirMSpar<-edit(AmidihirMSpar)
     AmidihirMSpar<-ymscheck(AmidihirMSpar)
     cat("\n")
     Amidihir.ms(length(AmidihirMSpar$subject),AmidihirMSpar$c,AmidihirMSpar$tau,AmidihirMSpar$ts,AmidihirMSpar$D,AmidihirMSpar$ht,AmidihirMSpar$age,AmidihirMSpar$smoke,AmidihirMSpar$Gender,AmidihirMSpar$CHF)
     note_for_convergence_plots()
     note_for_plot()
     convergence_plots_con()
     cat("------------------------------------------------------------------\n")
     cat("    --Aminophylline dihydrous IR output data information--        \n")
     note_for_Theirss_output()
     cat("------------------------------------------------------------------\n")
     show(samplesStats("*"))
     cat("\n")
     C<-TheIRsscpr(0.8,AmidihirMSpar$D,AmidihirMSpar$tau,AmidihirMSpar$ts)
     sim<-matrix(C[ ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Cmss_pr (mg/L)")
     output1<-coutput
     show(coutput)
     r=log(1.85-(samplesStats("cl_F")/samplesStats("v_F")))/(1.85-(samplesStats("cl_F")/samplesStats("v_F")))
     C<-TheIRsscpr(0.8,AmidihirMSpar$D,AmidihirMSpar$tau,r)
     sim<-matrix(C[ ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Cpss_pr (mg/L)")
     output2<-coutput
     show(coutput) 
     C<-TheIRsscpr(0.8,AmidihirMSpar$D,AmidihirMSpar$tau,AmidihirMSpar$tau)
     sim<-matrix(C[ ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Ctss_pr (mg/L)")
     output3<-coutput
     show(coutput)     
     cat("\n")  
     cal.again() 
}

==> tdm_2.2.1.tar.gz: tdm/R/all.Amidihirms.R <==
all.Amidihirms<-function(){
     cat("\n")                                                                       
     cat("--------------------------------------------------------------\n")
     cat("    --Aminophylline dihydrous IR input data information--     \n")
     note_for_Theirss_input()
     cat("--------------------------------------------------------------\n")
     cat("\n")
     note_for_close_window()
     AmidihirMSpar<-data.frame(subject=c(1,2),Gender=c(0),age=c(0),ht=c(0),CHF=c(0),smoke=c(0),D=c(0),tau=c(0),ts=c(0),c=c(0))
     AmidihirMSpar<-edit(AmidihirMSpar)
##     AmidihirMSpar<-ymscheck(AmidihirMSpar)
     cat("\n")
     Amidihir.ms(length(AmidihirMSpar$subject),AmidihirMSpar$c,AmidihirMSpar$tau,AmidihirMSpar$ts,AmidihirMSpar$D,AmidihirMSpar$ht,AmidihirMSpar$age,AmidihirMSpar$smoke,AmidihirMSpar$Gender,AmidihirMSpar$CHF)
     note_for_convergence_plots()
     note_for_plot()
     convergence_plots_con()
     cat("------------------------------------------------------------------\n")
     cat("    --Aminophylline dihydrous IR output data information--        \n")
     note_for_Theirss_output()
     cat("------------------------------------------------------------------\n")
     show(samplesStats("*"))
     cat("\n")
     C<-TheIRsscpr(0.8,AmidihirMSpar$D,AmidihirMSpar$tau,AmidihirMSpar$ts)
     sim<-matrix(C[ ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Cmss_pr (mg/L)")
     output1<-coutput
     show(coutput)
     r=log(1.85-(samplesStats("cl_F")/samplesStats("v_F")))/(1.85-(samplesStats("cl_F")/samplesStats("v_F")))
     C<-TheIRsscpr(0.8,AmidihirMSpar$D,AmidihirMSpar$tau,r)
     sim<-matrix(C[ ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Cpss_pr (mg/L)")
     output2<-coutput
     show(coutput) 
     C<-TheIRsscpr(0.8,AmidihirMSpar$D,AmidihirMSpar$tau,AmidihirMSpar$tau)
     sim<-matrix(C[ ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Ctss_pr (mg/L)")
     output3<-coutput
     show(coutput)     
     cat("\n")  
     cal.again() 
}
